# CNCF End User Stories Guidelines #

## Overview ##

The CNCF End User Stories Program features real-world use cases and the impact CNCF projects and cloud native technologies are having on end users’ businesses. End User stories build narratives around specific metrics, acting as a valuable resource for organizations considering adopting cloud native technologies and showcasing participating organizations as leaders in their field.

**There are a number of ways you can participate in the case study program. Please see further information and eligibility criteria below** 

* Publish a [written case study](#written-case-study) which appears on the homepage of CNCF.io 
  * Open to any end user organization working with CNCF graduated or incubating projects 
  * Case studies from vendor companies selling cloud native services to external organizations are not eligible
* Participate in an [End User Journey Report](#end-user-journey-report) and demonstrate how your organization has grown as technology leader 
  * Open to all Platinum and Gold End User Members 
* Leveraging CNCF’s [Online Programs](https://github.com/cncf/foundation/blob/master/online-programs-guidelines.md) to showcase a case study webinar or submit a pre-recorded video case study for our YouTube channels
  * Open to all CNCF members
* Participate in the [End User Lounge livestream](https://www.cncf.io/blog/2021/04/22/introducing-the-cncf-end-user-lounge-exclusive-live-streams-for-end-user-organizations/) - a program that offers exclusive live streams for end users to showcase how they navigate the cloud native ecosystem 
  * Open to all End User Members 


## Written Case Study ##

### Who can be featured in a case study? ###

Case studies feature organizations working with CNCF incubating or graduated projects.  If you are a CNCF member (companies that build and sell cloud native solutions to external organizations) and have customers with interesting use cases, you can suggest them for a case study. The resulting case study would be about your customer’s use case, and we would also be able to include some details about how you helped with the implementation.

As a rule, case studies feature:
* CNCF End Users (Companies that use cloud native technologies internally, but do not sell any cloud native services externally)
* Organizations working with CNCF incubating or graduated projects

All case studies must demonstrate at least one tangible business impact of CNCF incubating or graduated projects.
Examples from published case studies include:
* 60% of maintenance time saved for private image central repository - [JD.com and Harbor](https://www.cncf.io/case-studies/jdcom-harbor)
* Able to release 10x a day, instead of every quarter - [Vodafone and Kubernetes](https://www.cncf.io/case-studies/vodafone/)
* With 4,000 pods, 200 nodes, and 80,000 builds per month, adidas is now running 40% of its most critical, impactful systems on its cloud native platform. - [Adidas, Kubernetes and Prometheus](https://www.cncf.io/case-studies/adidas/) 
 

### Written Case Study Process ###

To empower our fast-growing end user community to tell their stories, case studies follow a self-service partnership model - leveraging internal knowledge and expediting the sign-off process, with editorial support and guidance provided by the CNCF.
 
The self-service partnership follows a five-step process:

**1. Proposal**
* End users submit a [case study proposal](https://forms.gle/3rexeb56aDuYNMga8)

**2. Review**
* casestudies@cncf.io team reviews proposal within 20 working days
* If the proposal meets the criteria, the end user is sent a [case study pack](https://drive.google.com/file/d/1a19vzDM7EZtAvBbJnkTeSVbvDp4z5Kex/view?usp=sharing) 
* If the proposal doesn’t meet the criteria, the casestudies@cncf.io team will provide feedback and the end user is invited to resubmit 

**3. Creation**
* End user writes case study
* End user submits case study and collateral outlined in case study pack

**4. Editing**
* CNCF reviews the case study and makes any necessary edits as suggestions
* Edits are based on the [style guide and case study criteria](https://github.com/cncf/foundation/blob/master/style-guide.md) 
* End user is welcome to make further edits or additions to the case study
* End user confirms when the draft is final and manages any approval processes

**5. Publishing**
* CNCF prepares the case study for publication
* End user will receive a preview link, to view the case study before it goes live. This is an opportunity for final tweaks, but not to add further information.
* Case study is published to <https://cncf.io/case-studies>
* Promotion cycle begins


### Sample Case Study: Spotify ###
An Early Adopter of Containers, [Spotify Is Migrating from Homegrown Orchestration to Kubernetes](https://www.cncf.io/case-study/spotify/)

An early adopter of microservices and Docker, Spotify had containerized microservices running across its fleet of VMs with a homegrown container orchestration system.

Kubernetes was a nice compliment to their homegrown system, so the migration to Kubernetes and other CNCF projects went smoothly. Spotify is using Kubernetes, Envoy, and gRPC.

Results:
* CPU utilization improved 2-3x
* Services creation went from an hour to seconds or minutes
* Spotify has thousands of microservices in production, 150+ running on Kubernetes.


### Promotion ###
Case studies are published on [cncf.io](https://www.cncf.io/newsroom/case-studies/), feature in rotating hero images on the cncf.io homepage, and, in some cases, features on specific project websites. 

CNCF markets the case studies online, through social media, blog promotion, and the CNCF newsletter. In some cases, the case study will be shared via the project Twitter account. End users are encouraged to leverage CNCF’s numerous marketing channels to amplify their case study. We ask that you share the case study on your platforms as well.


### To get started ###

Propose a case study and send it to the team directly with [this form](https://forms.gle/3rexeb56aDuYNMga8)

### Summary ###

If you have any questions or feedback about the Written Case Study program, please email casestudies@cncf.io.



# End User Journey Report # 

### Who can be featured in an end user journey report? ###

End User Journey Reports are comprehensive deep-dives, demonstrating how organizations have grown as cloud native technology leaders. EUJRs are open to CNCF Platinum and Gold End User Members who have developed mature cloud native systems. Participants are leaders in their field and want to use their position to inspire and educate others. 

### End User Journey Report Process ### 

EUJRs are managed, written and produced by CNCF, in close collaboration with End User Members.
Participants will need to:
* Complete initial proposal which covers:
  * How long have you been using CNCF projects?
  * Which projects do you use?
  * Has your organization contributed to a project/donated a project?
  * Do employees of your organization take an active role in CNCF -- for example, chairing committees, or speaking at KubeCon-CloudNativeCon?
* Nominate 1-2 employees to take part in an hour-long interview
* Possibly take part in a follow-up interviews to fact-check and clarify information 
* Approve written content
* Approve final designed content 

### Sample End User Journey Report: Spotify ### 

**Coming soon!** 

### Promotion ### 

End User Journey Reports are published on cncf.io and marketed through social media, blog promotion, and the CNCF newsletter. Participating End Users may be asked to join media interviews or speaking opportunities with CNCF leaders. 
End users are encouraged to leverage CNCF’s numerous marketing channels to amplify their End User Journey Report. We ask that you share the report on your platforms as well.

### To get started ### 

To participate in an End User Journey Report, submit a [proposal](https://forms.gle/y2wqydF1hVGBRXGEA)

### Summary ###

If you have any questions or feedback about the End User Journey Report program, please email casestudies@cncf.io.
