# CNCF Code of Conduct Committee Charter

## Purpose

The CNCF Code of Conduct Committee (“CoC Committee”) responds to, investigates, and resolves [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/main/code-of-conduct.md) incidents.

The Jurisdiction Policy describes the CoC Committee’s relationship to the Linux Foundation (LF) staff, who enforces the [Linux Foundation Events Code of Conduct](https://events.linuxfoundation.org/about/code-of-conduct/), and project-level Code of Conduct responders (e.g., the Kubernetes Code of Conduct Committee).

## Composition

The CoC Committee consists of 3 elected community members and 2 CNCF appointed staff members, plus alternates.

## Eligibility

To be eligible to serve as a primary or alternate member of the CoC Committee, an individual must not have violated the CNCF Code of Conduct within the prior 18 months.

Additionally, elected community member representatives are subject to the following eligibility criteria:
* Must be an active participant in the CNCF community, or previously been an active participant.
* Previous experience on an ethics committee or code of conduct committee, or other experience related to legal, HR, compliance, or supporting DEIB (diversity, equity, inclusion, & belonging) is valued but is not required.
* Must be a generally responsible human.
* Demonstration of integrity, professionalism, and positive influence within the CNCF community or other communities is highly valued.

## Elected Community Member Representatives

### Limit on Number of Representatives from a Single Company

To reduce the likelihood of multiple conflicts of interests arising for a particular incident, no more than 2 of the 6 (primary + alternate) elected community representatives may be from a single company. If more the 2 employees from the same company are among the 6 candidates with the highest number of votes, only the 2 employees from that company with the highest number of votes shall be elected.

### Election of Community Member Representatives

The community representatives will be elected by a vote of the [Technical Oversight Committee](https://www.cncf.io/people/technical-oversight-committee/) (TOC).

The 3 candidates receiving the highest number of votes will serve as primary representatives of the CoC Committee. The 3 candidates receiving the next highest number of votes shall serve as alternatives.

### Nomination of Community Member Representatives

The TOC will announce a request for nominations some time in [month to be determined] from anyone meeting the eligibility for candidacy guidelines. The TOC may request that TAG-Contributor Strategy or any other specific committee or group within the CNCF community submit nominations.

The TOC will accept nominations for at least 1 week and may choose to accept nominations for a longer period. After the announced nomination period closes, the TOC will hold a private ballot election using time-limited Condorcet ranking and use the Schulze method to break ties. The TOC will publicly announce the winners of the election.

### Term Lengths and Limits

Elected CoC Committee Members shall each serve for a 2 year term. There is no limit on the number of terms (consecutive or not) that an individual can serve on the CoC Committee.

### Resignation, Removals, and Vacancies

If any member of the CoC Committee is inactive on the committee for more than 6 months, it is highly encouraged that they resign, and if they do not resign, the remaining CoC Committee members may vote to remove them. 

If a primary elected committee member resigns, is removed, or becomes disqualified prior to the end of their term, the alternate who received the highest number of votes in the election will replace them as a primary committee member for the remainder of the term.

If an elected primary or alternate committee member resigns, is removed, or becomes disqualified prior to completion of their term, the CoC Committee will decide whether to continue operating with one fewer alternate member for the remainder of the term or ask the TOC to hold a special mid-cycle election to add another alternate to the CoC Committee.

## CNCF Staff Representatives

CNCF will appoint 2 staff members to serve on the CoC Committee as primary representatives. 

CNCF may appoint up to 2 alternate staff members to serve on the committee on an ongoing basis. Alternatively, in the event one of the primary CNCF staff representatives is unavailable or has a conflict of interest for a particular incident, CNCF may appoint an alternate staff representative just for that incident.

## Alternates  

Alternates do not participate in resolution of every incident; alternates participate only on an as needed basis to when a primary committee member is unavailable or has a conflict of interest, for the purpose of ensuring that multiple Community Members participate in resolution of every incident.

The CoC Committee may invite any individual who meets the eligibility requirements for serving on the committee to serve as an alternate for a particular incident.

## Linux Foundation Liaison

When a Code of Conduct incident is subject to both the CNCF Code of Conduct and the Linux Foundation Events Code of Conduct, the Linux Foundation may designate a liaison (the “LF Liaison”) to coordinate efforts between the Linux Foundation and the CoC Committee. The CoC Committee may ask that the LF Liaison may participate in CoC Committee discussions and meetings regarding the incident on a non-voting basis. If the CoC Committee does not invite the LF Liaison to participate in CoC Committee discussions, the CNCF staff members who serve on the committee will be responsible for coordinating and liaising with the Linux Foundation as needed.

## CNCF Governing Board Liaison

The CNCF Governing Board shall designate a representative to serve as a liaison (the "GB Liaison") to coordinate efforts between the Governing Board and CoC Committee when the CoC Committee deems such coordination to be in the best interests of the community. The GB Liaison shall not participate in the investigation (except as a witness if appropriate) or decision-making regarding how an incident should be resolved. The GB Liaison is required to comply with the [Confidentiality Policy](coc-incident-resolution-procedures.md#confidentiality-policy). 

## Information Sharing with TOC and Governing Board

The CoC Committee may provide to the TOC or the GB Liaison, and the GB Liaison may freely share with the Governing Board, non-confidential information and information that cannot be used to identify reporters or any victims or targets of harassment, including:
* Statistical information, such as number of incidents reported
* Procedural information, such as how the committee functions, whether a committee member or an external consultant is performing an investigation, and whether any committee members recused themselves due to a conflict of interest
* Systemic issues such as policy, governance, or cultural concerns that came to light as a result of the incident

Information that can be used to identify a reporter, victim, or target of harassment will not be provided to the TOC or a GB Liaison unless such reporter, victim, or targeted individual has consented to disclosure of their identity or their identity is already publicly known.

The GB Liaison shall not share confidential information concerning a specific incident with the Governing Board unless the CoC Committee has requested or authorized such sharing for a purpose specified by the CoC Committee. In such case, the GB Liaison shall clearly designate such information as confidential when sharing it with the Governing Board. 

## How Decisions Are Made

Decisions of the CoC Committee shall be made by consensus whenever possible. In the event consensus cannot be reached, decisions shall be made by majority vote of non-conflicted members of the CoC Committee. A decision to take temporary interim action in the event of an emergency may be taken by any individual CoC Committee member acting in good faith, and the CoC Committee shall review such action and decide whether to confirm or reverse such action. Any permanent action shall require approval of a majority of non-conflicted members of the CoC Committee. The CoC Committee may take action without a meeting if a majority of non-conflicted members express agreement in writing (e.g., email or slack) and none of the non-conflicted CoC Committee members either object to the proposed action or request a meeting to discuss the proposed action within 24 hours after the action is first proposed to the CoC Committee. In the absence of such agreement in writing, the CoC Committee may only take action during or after a meeting takes place at which the proposed action is discussed and agreed to by consensus or voted upon by a quorum of the non-conflicted members. A majority of non-conflicted members shall be deemed a quorum for purposes of a meeting. See the “[Conflict of Interest](https://github.com/cncf/foundation/blob/main/code-of-conduct/coc-incident-resolution-procedures.md#conflicts-of-interest)” section of the Incident Resolution Procedures for more information.

## External Support Resources

The CoC Committee may, in its discretion, engage external mediators, investigators, advisors, and consultants as needed to assist with resolution of CoC Incidents. Any such external resources shall not have a vote, and shall be required to maintain confidentiality in accordance with our [Confidentiality Policy](https://github.com/cncf/foundation/blob/main/code-of-conduct/coc-incident-resolution-procedures.md#confidentiality-policy).

## Incident Resolution Procedures

Please see our [Jurisdiction Policy](https://github.com/cncf/foundation/blob/main/code-of-conduct/coc-committee-jurisdiction-policy.md) and our [Incident Resolution Procedures](https://github.com/cncf/foundation/blob/main/code-of-conduct/coc-incident-resolution-procedures.md), which address:

-   How to submit a report
-   What information to share in your report
-   What happens after a report is submitted
-   Resolution
-   Information sharing
-   Confidentiality Policy
-   No retaliation
-   Conflicts of interest

## Amendments

Any amendments to this charter must be approved by the CNCF Governing Board consistent with the CNCF Charter.
    
## Licensing

This document is licensed under the [Creative Commons Attribution 4.0 International License](https://creativecommons.org/licenses/by/4.0/).
